Compute marginal posterior probabilities (slab probabilities) that data points have non-zero mean for the discretized spike-and-slab prior.
SSS_discrete_spike_slab(log_phi_psi, dLambda, show_progress = TRUE)Returns a vector with marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).
List {logphi, logpsi} containing two vectors of the same length n
that represent a preprocessed version of the data. logphi and logpsi should contain
the logs of the phi and psi densities of the data points, as produced for instance
by SSS_log_phi_psi_Laplace or SSS_log_phi_psi_Cauchy
Discretized Lambda prior, as generated by either discretize_Lambda or discretize_Lambda_beta.
Boolean that indicates whether to show a progress bar