Given prior Lambda=Beta(kappa,lambda) on the alpha-parameter in the spike-and-slab model, make a discretized version of Lambda that is only supported on a grid of approximately m * sqrt(n) discrete values of alpha. This discretized version of Lambda is required as input for SSS_discrete_spike_slab.
SSS_discretize_Lambda_beta(m = 20, n, kappa, lambda)List (alpha_grid, log_probs), where alpha_grid is a vector with the generated grid points, and log_probs are the logs of the prior probabilities of these grid points for the discretized Lambda prior.
A multiplier for the number of discretization points
The sample size
Parameter of the prior. Needs to be at least 0.5.
Parameter of the prior. Needs to be at least 0.5.