Learn R Programming

SequenceSpikeSlab (version 1.0.1)

SSS_hierarchical_prior: Compute marginal posterior probabilities (slab probabilities) that data points have non-zero mean for the hierarchical prior.

Description

Compute marginal posterior probabilities (slab probabilities) that data points have non-zero mean for the hierarchical prior.

Usage

SSS_hierarchical_prior(log_phi_psi, logprior, show_progress = TRUE)

Value

Returns a vector with marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).

Arguments

log_phi_psi

List {logphi, logpsi} containing two vectors of the same length n that represent a preprocessed version of the data. logphi and logpsi should contain the logs of the phi and psi densities of the data points, as produced for instance by SSS_log_phi_psi_Laplace or SSS_log_phi_psi_Cauchy

logprior

vector of length n+1 with components logprior[p]=log(pi_n(p)) for \(p=0,...,n\)

show_progress

Boolean that indicates whether to show a progress bar