Learn R Programming

SequenceSpikeSlab (version 1.0.1)

SSS_postmean_Cauchy: Compute posterior means of data points for the Cauchy(gamma) slab

Description

Compute posterior means of data points for the Cauchy(gamma) slab

Usage

SSS_postmean_Cauchy(x, logpsi, postprobs, sigma, gamma)

Value

Vector of n posterior means

Arguments

x

Data vector of length n

logpsi

Vector of length n that represents a preprocessed version of the data. It should contain the logs of the psi densities of the data points, as produced by SSS_log_phi_psi_Cauchy.

postprobs

Vector of marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).

sigma

standard deviation of observations

gamma

parameter of Cauchy slab density