Compute posterior means of data points for the Laplace(lambda) slab
SSS_postmean_Laplace(x, logpsi, postprobs, sigma, lambda)Vector of n posterior means
Data vector of length n
Vector of length n that represents a preprocessed version of the data.
It should contain the logs of the psi densities of the data points, as produced
by SSS_log_phi_psi_Laplace.
Vector of marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).
standard deviation of observations
parameter of Laplace slab density