Compute marginal posterior probabilities (slab probabilities) that data points have non-zero mean for the hierarchical prior.
SSS_hierarchical_prior(log_phi_psi, logprior, show_progress = TRUE)Returns a vector with marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).
List {logphi, logpsi} containing two vectors of the same length n
that represent a preprocessed version of the data. logphi and logpsi should contain
the logs of the phi and psi densities of the data points, as produced for instance
by SSS_log_phi_psi_Laplace or SSS_log_phi_psi_Cauchy
vector of length n+1 with components logprior[p]=log(pi_n(p)) for \(p=0,...,n\)
Boolean that indicates whether to show a progress bar