Compute posterior means of data points for the Cauchy(gamma) slab
SSS_postmean_Cauchy(x, logpsi, postprobs, sigma, gamma)Vector of n posterior means
Data vector of length n
Vector of length n that represents a preprocessed version of the data.
It should contain the logs of the psi densities of the data points, as produced
by SSS_log_phi_psi_Cauchy.
Vector of marginal posterior slab probabilities that \(x[i]\) has non-zero mean for \(i=1,...,n\).
standard deviation of observations
parameter of Cauchy slab density